import { visit } from 'unist-util-visit';
const attacher = options => {
    const { renderer } = options;
    return tree => {
        visit(tree, 'element', (node, _, parent) => {
            if (!parent || parent.tagName !== 'pre' || node.tagName !== 'code') {
                return;
            }
            const lang = getLanguage(node);
            const code = renderer(node, lang);
            parent.properties = code.properties;
            parent.children = code.children;
        });
    };
};
const getLanguage = (node) => {
    if (!node.properties) {
        return null;
    }
    const { className, dataLanguage } = node.properties;
    if (typeof dataLanguage === 'string') {
        return dataLanguage;
    }
    const classNames = Array.isArray(className) ? className : [];
    for (const cls of classNames) {
        if (typeof cls === 'string' && cls.slice(0, 9) === 'language-') {
            return cls.slice(9).toLowerCase();
        }
    }
    return null;
};
export default attacher;
